okcolors: Retrieve an okcolors Palette

View source: R/palettes.R

okcolorsR Documentation

Retrieve an okcolors Palette

Description

Returns n colors from a palette included in okcolors.

Usage

okcolors(palette = "obsession", n = 5, direction = 1)

Arguments

palette

Character. Name of the palette to use. See valid_palettes() for available options. Default is "obsession".

n

Integer. Number of colors to return. Default is 5.

direction

Integer. Use 1 for the palette order or -1 to reverse it. Default is 1.

Value

A character vector of hex color codes of length n.

Examples

okcolors("stone", 3)
okcolors("obsession", 7, direction = -1)


okcolors documentation built on July 2, 2026, 5:07 p.m.