valid_palettes: List Available Palettes in okcolors

View source: R/utils.R

valid_palettesR Documentation

List Available Palettes in okcolors

Description

Returns a character vector of all valid palette names supported by the okcolors package.

Usage

valid_palettes()

Value

A character vector with the names of available palettes.

Examples

valid_palettes()

okcolors documentation built on July 2, 2026, 5:07 p.m.