| okcolors | R Documentation |
Returns n colors from a palette included in okcolors.
okcolors(palette = "obsession", n = 5, direction = 1)
palette |
Character. Name of the palette to use. See |
n |
Integer. Number of colors to return. Default is |
direction |
Integer. Use |
A character vector of hex color codes of length n.
okcolors("stone", 3)
okcolors("obsession", 7, direction = -1)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.