| scale_fill_okcolors | R Documentation |
Applies a custom continuous or discrete fill scale to ggplot2 plots using a selected okcolors palette.
scale_fill_okcolors(
palette = "obsession",
discrete = FALSE,
direction = 1,
...
)
palette |
Character. Name of the palette to use. See |
discrete |
Logical. Whether to use a discrete scale ( |
direction |
Integer. Use |
... |
Additional arguments passed to |
A Scale object that can be added to a ggplot2 plot.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.