| valid_palettes | R Documentation |
Returns a character vector of all valid palette names supported by the okcolors package.
valid_palettes()
A character vector with the names of available palettes.
valid_palettes()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.